summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/uml.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:36 -0600
commit7716a5e605907a009e19f429cec4e6b5f346bd71 (patch)
tree16cf4a5d7a24db774f988022d514adefc75015c0 /umbrello/umbrello/uml.h
parent0117fbed932653a04aeef16b2ed7edee858959ac (diff)
downloadtdesdk-7716a5e605907a009e19f429cec4e6b5f346bd71.tar.gz
tdesdk-7716a5e605907a009e19f429cec4e6b5f346bd71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'umbrello/umbrello/uml.h')
-rw-r--r--umbrello/umbrello/uml.h146
1 files changed, 73 insertions, 73 deletions
diff --git a/umbrello/umbrello/uml.h b/umbrello/umbrello/uml.h
index dc4dcfec..6474f422 100644
--- a/umbrello/umbrello/uml.h
+++ b/umbrello/umbrello/uml.h
@@ -44,14 +44,14 @@ class KPlayerPopupSliderAction;
class XhtmlGenerator;
// KDE forward declarations
-class KActionMenu;
-class KRecentFilesAction;
+class TDEActionMenu;
+class TDERecentFilesAction;
class KStatusBarLabel;
-class KToggleAction;
+class TDEToggleAction;
class KDockWidget;
class KTabWidget;
-class KToolBarButton;
-class KPopupMenu;
+class TDEToolBarButton;
+class TDEPopupMenu;
// TQt forward declarations
class TQWidgetStack;
@@ -65,9 +65,9 @@ class TQCustomEvent;
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. An instance of UMLView creates your center view, which is connected
* to the window's Doc object.
- * UMLApp reimplements the methods that KMainWindow provides for main window handling and supports
- * full session management as well as using KActions.
- * @see KMainWindow
+ * UMLApp reimplements the methods that TDEMainWindow provides for main window handling and supports
+ * full session management as well as using TDEActions.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig
*
@@ -103,7 +103,7 @@ public:
/**
* Returns a pointer to the current document connected to the
- * KMainWindow instance.
+ * TDEMainWindow instance.
* Used by the View class to access the document object's methods.
*/
UMLDoc *getDocument() const;
@@ -352,7 +352,7 @@ protected:
void readOptions();
/**
- * Initializes the KActions of the application.
+ * Initializes the TDEActions of the application.
*/
void initActions();
@@ -363,33 +363,33 @@ protected:
void initStatusBar();
/**
- * Creates the centerwidget of the KMainWindow instance and
+ * Creates the centerwidget of the TDEMainWindow instance and
* sets it as the view.
*/
void initView();
/**
- * queryClose is called by KMainWindow on each closeEvent of a
+ * queryClose is called by TDEMainWindow on each closeEvent of a
* window. Counter to the default implementation (which only
* returns true), this calls saveModified() on the document object
* to ask if the document shall be saved if Modified; on cancel
* the closeEvent is rejected.
- * @see KMainWindow#queryClose
- * @see KMainWindow#closeEvent
+ * @see TDEMainWindow#queryClose
+ * @see TDEMainWindow#closeEvent
*
* @return True if window may be closed.
*/
virtual bool queryClose();
/**
- * queryExit is called by KMainWindow when the last
+ * queryExit is called by TDEMainWindow when the last
* window of the application is going to be closed during
* the closeEvent(). In contrast to the default
* implementation that just returns true, this calls
* saveOptions() to save the settings of the last
* window's properties.
- * @see KMainWindow#queryExit
- * @see KMainWindow#closeEvent
+ * @see TDEMainWindow#queryExit
+ * @see TDEMainWindow#closeEvent
*
* @return True if window may be closed.
*/
@@ -400,7 +400,7 @@ protected:
* during session end to the session config file,
* including saving the currently opened file by a
* temporary filename provided by TDEApplication.
- * @see KMainWindow#saveProperties
+ * @see TDEMainWindow#saveProperties
*/
virtual void saveProperties(TDEConfig *_cfg);
@@ -409,7 +409,7 @@ protected:
* application's state including the last opened files and
* documents by reading the temporary files saved by
* saveProperties()
- * @see KMainWindow#readProperties
+ * @see TDEMainWindow#readProperties
*/
virtual void readProperties(TDEConfig *_cfg);
@@ -911,66 +911,66 @@ private:
/** Refactoring assistant. */
RefactoringAssistant* m_refactoringAssist;
- //KAction pointers to enable/disable actions
- KAction* fileNew;
- KAction* fileOpen;
- KRecentFilesAction* fileOpenRecent;
- KAction* fileSave;
- KAction* fileSaveAs;
- KAction* fileClose;
- KAction* filePrint;
- KAction* fileQuit;
- KAction* fileExportDocbook;
- KAction* fileExportXhtml;
-
- KAction* editCut;
- KAction* editCopy;
- KAction* editPaste;
- KAction* editUndo;
- KAction* editRedo;
- KAction* selectAll;
- KAction* preferences;
-
- KActionMenu* newDiagram;
- KAction* classDiagram;
- KAction* sequenceDiagram;
- KAction* collaborationDiagram;
- KAction* useCaseDiagram;
- KAction* stateDiagram;
- KAction* activityDiagram;
- KAction* componentDiagram;
- KAction* deploymentDiagram;
- KAction* entityRelationshipDiagram;
- KAction* viewClearDiagram;
-
- KToggleAction* viewSnapToGrid;
- KToggleAction* viewShowGrid;
- KAction* viewExportImage;
- KAction* viewExportImageAll;
- KAction* viewProperties;
-
- KAction* zoom100Action;
+ //TDEAction pointers to enable/disable actions
+ TDEAction* fileNew;
+ TDEAction* fileOpen;
+ TDERecentFilesAction* fileOpenRecent;
+ TDEAction* fileSave;
+ TDEAction* fileSaveAs;
+ TDEAction* fileClose;
+ TDEAction* filePrint;
+ TDEAction* fileQuit;
+ TDEAction* fileExportDocbook;
+ TDEAction* fileExportXhtml;
+
+ TDEAction* editCut;
+ TDEAction* editCopy;
+ TDEAction* editPaste;
+ TDEAction* editUndo;
+ TDEAction* editRedo;
+ TDEAction* selectAll;
+ TDEAction* preferences;
+
+ TDEActionMenu* newDiagram;
+ TDEAction* classDiagram;
+ TDEAction* sequenceDiagram;
+ TDEAction* collaborationDiagram;
+ TDEAction* useCaseDiagram;
+ TDEAction* stateDiagram;
+ TDEAction* activityDiagram;
+ TDEAction* componentDiagram;
+ TDEAction* deploymentDiagram;
+ TDEAction* entityRelationshipDiagram;
+ TDEAction* viewClearDiagram;
+
+ TDEToggleAction* viewSnapToGrid;
+ TDEToggleAction* viewShowGrid;
+ TDEAction* viewExportImage;
+ TDEAction* viewExportImageAll;
+ TDEAction* viewProperties;
+
+ TDEAction* zoom100Action;
KPlayerPopupSliderAction* zoomAction;
- KAction* genAll;
- KAction* genWizard;
- KAction* importClasses;
- KAction* classWizard;
- KAction* deleteSelectedWidget;
- KAction* deleteDiagram;
+ TDEAction* genAll;
+ TDEAction* genWizard;
+ TDEAction* importClasses;
+ TDEAction* classWizard;
+ TDEAction* deleteSelectedWidget;
+ TDEAction* deleteDiagram;
#ifdef HAVE_DOT
- KAction* autolayout;
+ TDEAction* autolayout;
#endif
- KAction* changeTabLeft;
- KAction* changeTabRight;
- KAction* moveTabLeft;
- KAction* moveTabRight;
- KToolBarButton* m_newSessionButton;
- KPopupMenu* m_diagramMenu;
+ TDEAction* changeTabLeft;
+ TDEAction* changeTabRight;
+ TDEAction* moveTabLeft;
+ TDEAction* moveTabRight;
+ TDEToolBarButton* m_newSessionButton;
+ TDEPopupMenu* m_diagramMenu;
TQToolButton* m_closeDiagramButton;
- KToggleAction* viewToolBar;
- KToggleAction* viewStatusBar;
+ TDEToggleAction* viewToolBar;
+ TDEToggleAction* viewStatusBar;
WorkToolBar* toolsbar;
TQTimer* m_clipTimer;
TQTimer* m_copyTimer;